@@ -118,20 +118,37 @@ class RethinkDBClient(BaseStorageClient):
     async def find(self, obj_cls, object_space, object_type, filter):
         await self.init_table(object_space, object_type, obj_cls._indexes)
 
+        dynamic_fields = []
+        static_fields = {}
+
         if filter.order_direction == 'asc':
             order_by_expr = r.asc(filter.order_by)
         else:
             order_by_expr = r.desc(filter.order_by)
 
-        result = await r.db(
+        for field_key, field_val in filter.fields.items():
+            if isinstance(field_val, dict):
+                if '_contains' in field_val:
+                    dynamic_fields.append(
+                        r.row[field_key].contains(field_val['_contains'])
+                    )
+            else:
+                static_fields[field_key] = field_val
+
+        query = r.db(
             object_space
         ).table(
             object_type
         ).order_by(
             index=order_by_expr
         ).filter(
-            filter.fields
-        ).skip(
+            static_fields
+        )
+
+        for dynamic_field in dynamic_fields:
+            query = query.filter(dynamic_field)
+
+        result = await query.skip(
             filter.page_size*filter.page_no
         ).limit(
             filter.page_size
